==> hyperdiv-0.0.10-py3-none-any.whl: hyperdiv/components/drawer.py <==
from ..elements.props import OptionProp
from .. import elements as el
from .combo import combo


class drawer_element(el.modal):
    name = "modal"
    # Override position to only support left/right
    position = OptionProp("left", ("left", "right"))


class drawer(combo):
    """A drawer is a modal that opens on the left or right with 100%
    height and customizable width."""

    def __init__(self, **props):
        with drawer_element(
            width=300,
            height="100%",
            padding=8,
            gap=8,
            horizontal_scroll=True,
            vertical_scroll=True,
        ) as self.element:
            self.content_slot = el.slot()
        super().__init__(
            (
                self.element,
                ["position", "width", "opened", "padding", "gap"] + el.input_props,
            ),
            init=props,
        )

    def content(self, *args, **kwargs):
        """[public]
        Using this method, you can add arbitrary content into the
        drawer. The `args` and `kwargs` are forwarded to the
        underlying [`box`](/components/box).

        Example:

        ```py
        drawer = hd.drawer()
        with drawer.content(gap=8):
            hd.text("Hello")
        ```
        """
        with self.content_slot:
            return el.container(*args, **kwargs)


class tray_element(el.modal):
    name = "modal"
    # Override position to only support bottom/top
    position = OptionProp("bottom", ("top", "bottom"))


class tray(combo):
    """
    A tray is a modal that opens on the top or bottom with 100% width
    and customizable height. Arbitrary content can be nested in the
    tray, and its `opened` prop is used to control whether the tray is
    visible.

    Example:

    ```py
    with hd.box(gap=16):
        position = hd.radio_group(
            "Position", "top", ("top", "bottom")
        )

        t = hd.tray(position=position.selected)
        with t.content(
            padding=8,
            align="center",
            justify="center",
            gap=8,
            height="100%"
        ):
            hd.text("I'm a tray.")
            hd.text("Click outside me to close me.")

        if hd.button("Open Tray").clicked:
            t.opened = True
    ```
    """

    def __init__(self, **props):
        with tray_element(
            width="100%",
            height=200,
            padding=8,
            gap=8,
            horizontal_scroll=True,
            vertical_scroll=True,
        ) as self.element:
            self.content_slot = el.slot()
        super().__init__(
            (
                self.element,
                ["position", "height", "opened", "padding", "gap"] + el.input_props,
            ),
            init=props,
        )

    def content(self, *args, **kwargs):
        """[public]
        Using this method, you can add arbitrary content into the
        tray. The `args` and `kwargs` are forwarded to the
        underlying [`box`](/components/box).

        Example:

        ```py
        tray = hd.tray()
        with tray.content(gap=8):
            hd.text("Hello")
        ```
        """
        with self.content_slot:
            return el.container(*args, **kwargs)

==> hyperdiv-0.0.13-py3-none-any.whl: hyperdiv/components/drawer.py <==
from ..elements.props import OptionProp
from .. import elements as el
from .combo import combo


class drawer_element(el.modal):
    name = "modal"
    # Override position to only support left/right
    position = OptionProp("left", ("left", "right"))


class drawer(combo):
    """A drawer is a modal that opens on the left or right with 100%
    height and customizable width."""

    def __init__(self, **props):
        with drawer_element(
            width=300,
            height="100%",
            padding=8,
            gap=8,
            horizontal_scroll=True,
            vertical_scroll=True,
        ) as self.element:
            self.content_slot = el.slot()
        super().__init__(
            (
                self.element,
                ["position", "width", "opened", "padding", "gap"] + el.input_props,
            ),
            init=props,
        )

    def content(self, *args, **kwargs):
        """[public]
        Returns the [box](/components/box) that holds the drawer's
        content. The `*args` and `**kwargs` are passed to the `box`
        constructor verbatim. You can use this method to add arbitrary
        content into the drawer.

        Example:

        ```py
        drawer = hd.drawer()
        with drawer.content(padding=8):
            hd.text("Hello")
        ```
        """
        with self.content_slot:
            return el.container(*args, **kwargs)


class tray_element(el.modal):
    name = "modal"
    # Override position to only support bottom/top
    position = OptionProp("bottom", ("top", "bottom"))


class tray(combo):
    """
    A tray is a modal that opens on the top or bottom with 100% width
    and customizable height. Arbitrary content can be nested in the
    tray, and its `opened` prop is used to control whether the tray is
    visible.

    Example:

    ```py
    with hd.box(gap=16):
        position = hd.radio_group(
            "Position", "top", ("top", "bottom")
        )

        t = hd.tray(position=position.selected)
        with t.content(
            padding=8,
            align="center",
            justify="center",
            gap=8,
            height="100%"
        ):
            hd.text("I'm a tray.")
            hd.text("Click outside me to close me.")

        if hd.button("Open Tray").clicked:
            t.opened = True
    ```
    """

    def __init__(self, **props):
        with tray_element(
            width="100%",
            height=200,
            padding=8,
            gap=8,
            horizontal_scroll=True,
            vertical_scroll=True,
        ) as self.element:
            self.content_slot = el.slot()
        super().__init__(
            (
                self.element,
                ["position", "height", "opened", "padding", "gap"] + el.input_props,
            ),
            init=props,
        )

    def content(self, *args, **kwargs):
        """[public]
        Using this method, you can add arbitrary content into the
        tray. The `args` and `kwargs` are forwarded to the
        underlying [`box`](/components/box).

        Example:

        ```py
        tray = hd.tray()
        with tray.content(gap=8):
            hd.text("Hello")
        ```
        """
        with self.content_slot:
            return el.container(*args, **kwargs)
